<?php
/**
 * File to define the custom hook functions 
 *
 * @package Mystery Themes
 * @subpackage Owner
 * @since 1.0.0
 *
 */

/**
 * function for top header section wrapper start
 */
if( ! function_exists( 'owner_top_header_wrapper_start' ) ):
	function owner_top_header_wrapper_start() {
		echo '<div class="top-header-holder clearfix"> <div class="mt-container">';
	}
endif;

/**
 * function for top header info section
 */
if( ! function_exists( 'owner_top_header_info' ) ):
	function owner_top_header_info() {
		$top_header_address = get_theme_mod( 'header_address', '' );
		$top_header_email = get_theme_mod( 'header_email', '' );
		$top_header_phone = get_theme_mod( 'header_phone', '' );

		echo '<div class="top-left-holder">';
		if( !empty( $top_header_address ) ) {
			echo '<span class="top-address top-info">'. esc_html( $top_header_address ) .'</span>';
		}
		if( !empty( $top_header_email ) ) {
			echo '<span class="top-email top-info">'. antispambot( $top_header_email ) .'</span>';
		}
		if( !empty( $top_header_phone ) ) {
			echo '<span class="top-phone top-info">'. esc_html( $top_header_phone ) .'</span>';
		}
		echo '</div><!--. top-left-holder -->';
	}
endif;

/**
 * function for top header social icons
 */
if( !function_exists( 'owner_social_icons' ) ):
	function owner_social_icons() {
		$fb_link  = get_theme_mod( 'fb_link', '' );
		$tw_link  = get_theme_mod( 'tw_link', '' );
		$ln_link  = get_theme_mod( 'ln_link', '' );
		$pin_link = get_theme_mod( 'pin_link', '' );
		$gp_link  = get_theme_mod( 'gp_link', '' );
		$yt_link  = get_theme_mod( 'yt_link', '' );

		echo '<div class="social-icons-holder">';
			if( !empty( $fb_link ) ) {
				echo '<a href="'. esc_url( $fb_link ) .'"><span class="mt-social-icon fa fa-facebook"></span></a>';
			}
			if( !empty( $tw_link ) ) {
				echo '<a href="'. esc_url( $tw_link ) .'"><span class="mt-social-icon fa fa-twitter"></span></a>';
			}
			if( !empty( $ln_link ) ) {
				echo '<a href="'. esc_url( $ln_link ) .'"><span class="mt-social-icon fa fa-linkedin"></span></a>';
			}
			if( !empty( $pin_link ) ) {
				echo '<a href="'. esc_url( $pin_link ) .'"><span class="mt-social-icon fa fa-pinterest"></span></a>';
			}
			if( !empty( $gp_link ) ) {
				echo '<a href="'. esc_url( $gp_link ) .'"><span class="mt-social-icon fa fa-google-plus"></span></a>';
			}
			if( !empty( $yt_link ) ) {
				echo '<a href="'. esc_url( $yt_link ) .'"><span class="mt-social-icon fa fa-youtube"></span></a>';
			}
		echo '</div><!-- .social-icons-holder -->';
	}
endif;

/**
 * function for top header section wrapper end
 */
if( ! function_exists( 'owner_top_header_wrapper_end' ) ):
	function owner_top_header_wrapper_end() {
		echo '</div></div><!-- .top-header-holder -->';
	}
endif;


add_action( 'owner_top_header', 'owner_top_header_wrapper_start', 5 );
add_action( 'owner_top_header', 'owner_top_header_info', 10 );
add_action( 'owner_top_header', 'owner_social_icons', 15 );
add_action( 'owner_top_header', 'owner_top_header_wrapper_end', 25 );


/**
 * function for slider wrapper start
 */
if( ! function_exists( 'owner_slider_wrapper_start' ) ):
	function owner_slider_wrapper_start() {
		echo '<div class="owner-slider-wrapper">';
	}
endif;

/**
 * function for slider content
 */
if( ! function_exists( 'owner_slider_content' ) ):
	function owner_slider_content() {
		$slider_cat_id = get_theme_mod( 'owner_slider_category', 0 );
		if( empty( $slider_cat_id ) ) {
			return;
		}
		$slider_args = array(
				'post_type' 	=> 'post',
				'category__in'	=> absint( $slider_cat_id )
			);
		$slider_query = new WP_Query( $slider_args );
		if( $slider_query->have_posts() ) {
			echo '<ul class="homepage-slider">';
			while ( $slider_query->have_posts() ) {
				$slider_query->the_post();
				$image_id = get_post_thumbnail_id();
				$image_path = wp_get_attachment_image_src( $image_id, 'full', true );
				$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
	?>
				<li>
					<div class="single-slide">
						<div class="slider-overlay"> </div>
						<div class="slide-thumb"><img src="<?php echo esc_url( $image_path[0] ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>" /></div>
						<div class="slider-content-wraper">
							<div class="mt-container">
								<h2 class="slide-title"><?php the_title(); ?></h2>
								<div class="slide-content"><?php the_content(); ?></div>
							</div>
						</div>
					</div>
				</li>
	<?php
			}
			echo '</ul>';
		}
	}
endif;

/**
 * function for slider wrapper end
 */
if( ! function_exists( 'owner_slider_wrapper_end' ) ):
	function owner_slider_wrapper_end() {
		echo '</div><!-- .owner-slider-wrapper -->';
	}
endif;

add_action( 'owner_slider_section', 'owner_slider_wrapper_start', 5 );
add_action( 'owner_slider_section', 'owner_slider_content', 10 );
add_action( 'owner_slider_section', 'owner_slider_wrapper_end', 15 );